@@ -17,13 +17,13 @@
 
 import sys
 import string
-import textwrap
 import subprocess
 import plistlib
 import os
 import re
 import support
 import errno
+import tempfile
 
 from collections import namedtuple
 from xml.parsers.expat import ExpatError
@@ -54,7 +54,7 @@ ENTITLE_APP_ID_KEY = "application-identifier"
 ENTITLE_APS_ENV_KEY = "aps-environment"
 
 # Filename for deprecated plist conversion output
-DEPRECATED_PLIST_PATH = "/tmp/ConvertedAirshipConfig.plist"
+CONVERTED_DEPRECATED_PLIST = "ConvertedAirshipConfig.plist"
 
 # APNS/UA Sever names
 PRODUCTION_SERVER = "production"
@@ -242,17 +242,19 @@ def convert_deprecated_plist_at_path(path_to_plist):
     :return: Converted plist or None on error
     :rtype: dict
     """
+
+    deprecated_plist_path = os.path.join(tempfile.mkdtemp(),
+                                         CONVERTED_DEPRECATED_PLIST)
     plutil_command = ["/usr/bin/plutil", "-convert", "xml1", path_to_plist,
-                      "-o", DEPRECATED_PLIST_PATH]
+                      "-o", deprecated_plist_path]
     try:
         subprocess.check_call(plutil_command)
     except subprocess.CalledProcessError as error:
-        log.error("plutil conversion failed with error code %s" %
-                  str(error.errno))
+        log.error("plutil conversion failed with error code " + error.message)
         return
 
     try:
-        plist = plistlib.readPlist(DEPRECATED_PLIST_PATH)
+        plist = plistlib.readPlist(deprecated_plist_path)
     except ExpatError as error:
         log.error("""Cannot read converted plist, please check the format, and
                   possibly convert to the new style Error:%s""", error.message)
@@ -462,7 +464,7 @@ class VerificationInformation(object):
             else:
                 # If not a bool or string, quit
                 log.error(AIRSHIP_CONFIG_PARSE_FAIL)
-                sys.exit(EXIT_FAILURE)
+                sys.exit(support.EXIT_FAILURE)
         return is_production
 
     def key_secret(self):
