@@ -23,17 +23,16 @@ import os
 import support
 import iossupport
 import androidsupport
+import package_info
 
 from iossupport import VerificationInformation
 
 
 def display_version():
-    """Display the library version to stdout"""
+    """Display the version number and usage if desired"""
+
+    print("Version:%s" % package_info.current_version())
 
-    import pkg_resources
-    version = pkg_resources.require("uaverify")[0].version
-    print("Version %s" % version)
-    return support.EXIT_SUCCESS
 
 NO_CONFIG_PLIST_ERROR = """
 No AirshipConfig.plist in app bundle. Without the configuration plist the
@@ -45,15 +44,18 @@ code is slated for a future release.
 class IosVerify(object):
     """ Verify the build with Urban Airship """
 
-    def __init__(self):
-        iossupport.clean()
-
     def execute_xcode_verify(self):
         """Execute all build verification tasks"""
 
         # Setup logger
         log = logging.getLogger(support.UA_LOGGER)
 
+        if self.version:
+            display_version()
+            return support.EXIT_SUCCESS
+
+        iossupport.clean()
+
         if self.diagnostic:
             log.info("Setting up diagnostic logging")
             support.setup_diagnostic_logging()
@@ -143,7 +145,12 @@ class AndroidVerify(object):
     def execute_android_verify(self):
         """Verify the android build"""
 
-        log = support.log
+        # Setup logger
+        log = logging.getLogger(support.UA_LOGGER)
+
+        if self.version:
+            display_version()
+            return support.EXIT_SUCCESS
 
         if self.diagnostic:
             log.info("Setting up diagnostic logging")
@@ -263,14 +270,12 @@ def ios_main():
                         help="Write out diagnostic information to a file")
 
     parser.add_argument('--plist', type=str,
-                help="Name of the configuration plist, "
-                     "defaults to \"AirshipConfig.plist\" ")
+                        help="Name of the configuration plist, "
+                             "defaults to \"AirshipConfig.plist\" ")
 
     parser.add_argument('-v', '--version', action="store_true",
                         help="Display version number and exit")
 
-    args = parser.parse_args()
-
     # Short circuit if there are no command line args
     if len(sys.argv) <= 1:
         display_version()
@@ -281,10 +286,6 @@ def ios_main():
     verify = IosVerify()
     parser.parse_args(namespace=verify)
 
-    if verify.version:
-        display_version()
-        return support.EXIT_SUCCESS
-
     success = verify.execute_xcode_verify()
     # There is the possibility of a file logger
     logging.shutdown()
@@ -307,6 +308,7 @@ If your application has more than one AndroidManifest.xml file, use this flag
 to pass the path of the manifest file to use for verification.
 """
 
+
 def android_arg_parser():
     """Setup the arg parser for the Android tool"""
 
@@ -344,10 +346,6 @@ def android_main():
     verify = AndroidVerify()
     parser.parse_args(namespace=verify)
 
-    if verify.version:
-        display_version()
-        return support.EXIT_SUCCESS
-
     success = verify.execute_android_verify()
     # There is the possibility of a file logger
     logging.shutdown()
